@@ -17,7 +17,7 @@ This package is inherited by I<Net::Blogger::Engine::Base> and provides helper m
 package Net::Blogger::API::Extended;
 use strict;
 
-$Net::Blogger::API::Extended::VERSION   = 0.1.2;
+$Net::Blogger::API::Extended::VERSION   = '0.1.3';
 @Net::Blogger::API::Extended::ISA       = qw ( Exporter );
 @Net::Blogger::API::Extended::EXPORT    = qw ();
 @Net::Blogger::API::Extended::EXPORT_OK = qw ();
@@ -353,7 +353,7 @@ sub _TrimPostBody {
 
 =head1 VERSION
 
-0.1.2
+0.1.3
 
 =head1 NAME
 
@@ -361,7 +361,7 @@ Aaron Straup Cope
 
 =head1 DATE
 
-April 15, 2002
+May 04, 2002
 
 =head1 SEE ALSO
 
@@ -371,6 +371,16 @@ L<Net::Blogger::API::Core>
 
 =head1 CHANGES
 
+=head2 0.1.3
+
+=over
+
+=item *
+
+Added quotes to I<$VERSION>
+
+=back
+
 =head2 0.1.2
 
 =over
